@@ -31,6 +31,7 @@
 #include "storage/shared-base.h"
 #include "exports.h"
 
+class Buddy;
 class Contact;
 class StoragePoint;
 
@@ -50,16 +51,15 @@ public:
 	Avatar(const Avatar &copy);
 	virtual ~Avatar();
 
-	QString filePath();
-	void setFilePath(const QString &filePath);
 	virtual void storeAvatar();
 
 	KaduSharedBase_PropertyBoolRead(Empty)
-	KaduSharedBase_Property(Buddy, avatarBuddy, AvatarBuddy)
-	KaduSharedBase_Property(Contact, avatarContact, AvatarContact)
-	KaduSharedBase_Property(QDateTime, lastUpdated, LastUpdated)
-	KaduSharedBase_Property(QDateTime, nextUpdate, NextUpdate)
-	KaduSharedBase_Property(QPixmap, pixmap, Pixmap)
+	KaduSharedBase_PropertyCRW(Buddy, avatarBuddy, AvatarBuddy)
+	KaduSharedBase_PropertyCRW(Contact, avatarContact, AvatarContact)
+	KaduSharedBase_PropertyCRW(QDateTime, lastUpdated, LastUpdated)
+	KaduSharedBase_PropertyCRW(QDateTime, nextUpdate, NextUpdate)
+	KaduSharedBase_PropertyCRW(QPixmap, pixmap, Pixmap)
+	KaduSharedBase_PropertyCRW(QString, filePath, FilePath)
 
 };
 
