@@ -38,6 +38,8 @@
 #include "gui/widgets/chat-messages-view.h"
 #include "gui/widgets/chat-widget.h"
 #include "gui/widgets/preview.h"
+#include "icons/kadu-icon.h"
+#include "identities/identity.h"
 #include "parser/parser.h"
 #include "protocols/protocol-factory.h"
 #include "misc/misc.h"
@@ -149,14 +151,14 @@ void AdiumChatStyleEngine::appendChatMessage(HtmlMessagesRenderer *renderer, Mes
 		Message last = lastMessage->message();
 
 		includeHeader =
-			msg.type() == Message::TypeSystem ||
-			last.type() == Message::TypeSystem ||
+			msg.type() == MessageTypeSystem ||
+			last.type() == MessageTypeSystem ||
 			msg.messageSender() != last.messageSender() ||
 			msg.receiveDate().toTime_t() - last.receiveDate().toTime_t() > (ChatStylesManager::instance()->cfgNoHeaderInterval() * 60);
 	}
 	switch (msg.type())
 	{
-		case Message::TypeReceived:
+		case MessageTypeReceived:
 		{
 			if (includeHeader)
 				formattedMessageHtml = CurrentStyle.incomingHtml();
@@ -164,7 +166,7 @@ void AdiumChatStyleEngine::appendChatMessage(HtmlMessagesRenderer *renderer, Mes
 				formattedMessageHtml = CurrentStyle.nextIncomingHtml();
 			break;
 		}
-		case Message::TypeSent:
+		case MessageTypeSent:
 		{
 			if (includeHeader)
 				formattedMessageHtml = CurrentStyle.outgoingHtml();
@@ -172,7 +174,7 @@ void AdiumChatStyleEngine::appendChatMessage(HtmlMessagesRenderer *renderer, Mes
 				formattedMessageHtml = CurrentStyle.nextOutgoingHtml();
 			break;
 		}
-		case Message::TypeSystem:
+		case MessageTypeSystem:
 		{
 			formattedMessageHtml = CurrentStyle.statusHtml();
 			break;
@@ -183,15 +185,18 @@ void AdiumChatStyleEngine::appendChatMessage(HtmlMessagesRenderer *renderer, Mes
 	}
 
 	formattedMessageHtml = replacedNewLine(replaceKeywords(CurrentStyle.baseHref(), formattedMessageHtml, message), QLatin1String(" "));
-	formattedMessageHtml.replace('\'', QLatin1String("\\'"));
 	formattedMessageHtml.replace('\\', QLatin1String("\\\\"));
-	formattedMessageHtml.prepend("<span>");
+	formattedMessageHtml.replace('\'', QLatin1String("\\'"));
+	if (!message->message().id().isEmpty())
+		formattedMessageHtml.prepend(QString("<span id=\"message_%1\">").arg(message->message().id()));
+	else
+		formattedMessageHtml.prepend("<span>");
 	formattedMessageHtml.append("</span>");
 
 	if (includeHeader)
-		renderer->webPage()->mainFrame()->evaluateJavaScript("appendMessage(\'"+ formattedMessageHtml +"\')");
+		renderer->webPage()->mainFrame()->evaluateJavaScript("appendMessage('"+ formattedMessageHtml +"')");
 	else
-		renderer->webPage()->mainFrame()->evaluateJavaScript("appendNextMessage(\'"+ formattedMessageHtml +"\')");
+		renderer->webPage()->mainFrame()->evaluateJavaScript("appendNextMessage('"+ formattedMessageHtml +"')");
 
 	renderer->setLastMessage(message);
 }
@@ -213,7 +218,7 @@ void AdiumChatStyleEngine::refreshView(HtmlMessagesRenderer *renderer, bool useT
 	else
 	{
 		styleBaseHtml.replace(styleBaseHtml.lastIndexOf("%@"), 2, (CurrentStyle.styleViewVersion() < 3 && CurrentStyle.defaultVariant() == CurrentStyle.currentVariant()) ? CurrentStyle.mainHref() : "Variants/" + CurrentStyle.currentVariant());
-		styleBaseHtml.replace(styleBaseHtml.lastIndexOf("%@"), 2, (CurrentStyle.styleViewVersion() < 3) ? "s" : "@import url( \"" + CurrentStyle.mainHref() + "\" );");
+		styleBaseHtml.replace(styleBaseHtml.lastIndexOf("%@"), 2, (CurrentStyle.styleViewVersion() < 3) ? "" : QString("@import url( \"" + CurrentStyle.mainHref() + "\" );"));
 	}
 
 
@@ -296,7 +301,7 @@ void AdiumChatStyleEngine::prepareStylePreview(Preview *preview, QString styleNa
 	else
 	{
 		styleBaseHtml.replace(styleBaseHtml.lastIndexOf("%@"), 2, (style.styleViewVersion() < 3 && style.defaultVariant() == style.currentVariant()) ? style.mainHref() : "Variants/" + style.currentVariant());
-		styleBaseHtml.replace(styleBaseHtml.lastIndexOf("%@"), 2, (style.styleViewVersion() < 3) ? "s" : "@import url( \"" + style.mainHref() + "\" );");
+		styleBaseHtml.replace(styleBaseHtml.lastIndexOf("%@"), 2, (style.styleViewVersion() < 3) ? "s" : QString("@import url( \"" + style.mainHref() + "\" );"));
 	}
 
 	preview->page()->mainFrame()->setHtml(styleBaseHtml);
@@ -306,14 +311,20 @@ void AdiumChatStyleEngine::prepareStylePreview(Preview *preview, QString styleNa
 
 	QString outgoingHtml(replacedNewLine(replaceKeywords(style.baseHref(), style.outgoingHtml(), message), QLatin1String(" ")));
 	outgoingHtml.replace('\'', QLatin1String("\\'"));
-	outgoingHtml.prepend("<span>");
+	if (!message->message().id().isEmpty())
+		outgoingHtml.prepend(QString("<span id=\"message_%1\">").arg(message->message().id()));
+	else
+		outgoingHtml.prepend("<span>");
 	outgoingHtml.append("</span>");
 	preview->page()->mainFrame()->evaluateJavaScript("appendMessage(\'" + outgoingHtml + "\')");
 
 	message = qobject_cast<MessageRenderInfo *>(preview->getObjectsToParse().at(1));
 	QString incomingHtml(replacedNewLine(replaceKeywords(style.baseHref(), style.incomingHtml(), message), QLatin1String(" ")));
 	incomingHtml.replace('\'', QLatin1String("\\'"));
-	incomingHtml.prepend("<span>");
+	if (!message->message().id().isEmpty())
+		incomingHtml.prepend(QString("<span id=\"message_%1\">").arg(message->message().id()));
+	else
+		incomingHtml.prepend("<span>");
 	incomingHtml.append("</span>");
 	preview->page()->mainFrame()->evaluateJavaScript("appendMessage(\'" + incomingHtml + "\')");
 
@@ -394,7 +405,7 @@ QString AdiumChatStyleEngine::replaceKeywords(const QString &styleHref, const QS
 	{
 		result.replace(QString("%service%"), msg.messageChat().chatAccount().protocolHandler()->protocolFactory()->displayName());
 		// Replace protocolIcon (sender statusIcon). TODO:
-		result.replace(QString("%senderStatusIcon%"), msg.messageChat().chatAccount().protocolHandler()->protocolFactory()->iconPath());
+		result.replace(QString("%senderStatusIcon%"), msg.messageChat().chatAccount().protocolHandler()->protocolFactory()->icon().fullPath());
 	}
 	else
 	{
@@ -422,7 +433,7 @@ QString AdiumChatStyleEngine::replaceKeywords(const QString &styleHref, const QS
 
 	// Replace userIconPath
 	QString photoPath;
-	if (msg.type() == Message::TypeReceived)
+	if (msg.type() == MessageTypeReceived)
 	{
 		result.replace(QString("%messageClasses%"), "message incoming");
 
@@ -433,7 +444,7 @@ QString AdiumChatStyleEngine::replaceKeywords(const QString &styleHref, const QS
 		else
 			photoPath = webKitPath(styleHref + QLatin1String("Incoming/buddy_icon.png"));
 	}
-	else if (msg.type() == Message::TypeSent)
+	else if (msg.type() == MessageTypeSent)
 	{
    		result.replace(QString("%messageClasses%"), "message outgoing");
 		Avatar avatar = msg.messageChat().chatAccount().accountContact().contactAvatar();
@@ -468,9 +479,29 @@ QString AdiumChatStyleEngine::replaceKeywords(const QString &styleHref, const QS
 		result.replace(textPos, senderColorRegExp.cap(0).length(), doLight ? lightColorName : colorName);
 	}
 
-	// Replace message TODO: do sth with formatMessage
-	QString messageText = QString("<span>") + formatMessage(message->htmlMessageContent()) + QString("</span>");
+// Replace message TODO: do sth with formatMessage
+	QString messageText = formatMessage(message->htmlMessageContent());
+
+	if (!message->message().id().isEmpty())
+		messageText.prepend(QString("<span id=\"message_%1\">").arg(message->message().id()));
+	else
+		messageText.prepend("<span>");
+	messageText.append("</span>");
+
+	result.replace(QString("%messageId%"), message->message().id());
+	result.replace(QString("%messageStatus%"), QString::number(message->message().status()));
+
 	result.replace(QString("%message%"), messageText);
 
 	return result;
 }
+
+void AdiumChatStyleEngine::messageStatusChanged(HtmlMessagesRenderer *renderer, Message message, MessageStatus status)
+{
+	renderer->webPage()->mainFrame()->evaluateJavaScript(QString("adium_messageStatusChanged(\"%1\", %2);").arg(message.id()).arg((int)status));
+}
+
+void AdiumChatStyleEngine::contactActivityChanged(HtmlMessagesRenderer *renderer, ChatStateService::ContactActivity state, const QString &message, const QString &name)
+{
+	renderer->webPage()->mainFrame()->evaluateJavaScript(QString("adium_contactActivityChanged(%1, \"%2\", \"%3\");").arg((int)state).arg(message).arg(name));
+}
