@@ -21,6 +21,7 @@
  */
 
 #include <QtGui/QFileDialog>
+#include <QtGui/QImageReader>
 #include <QtGui/QLabel>
 #include <QtGui/QPushButton>
 #include <QtGui/QVBoxLayout>
@@ -103,12 +104,14 @@ void BuddyAvatarWidget::buttonClicked()
 
 void BuddyAvatarWidget::changeAvatar()
 {
-	QString newAvatar = QFileDialog::getOpenFileName(this, tr("Select new photo"), QString(), "Image Files (*.png *.jpg *.bmp)", 0);
+	QString newAvatar = QFileDialog::getOpenFileName(this, tr("Select new photo"), QString(), tr("Images (*.png *.jpg *.bmp);;All Files (*)"), 0);
 	if (newAvatar.isEmpty())
 		return;
 
-	QPixmap pixmap;
-	if (pixmap.load(newAvatar))
+	QImageReader imageReader(newAvatar);
+	QPixmap pixmap = QPixmap::fromImageReader(&imageReader);
+
+	if (!pixmap.isNull())
 	{
 		showAvatar(newAvatar);
 		BuddyAvatarPixmap = pixmap;
