@@ -23,7 +23,6 @@
 
 #include <QtGui/QCheckBox>
 #include <QtGui/QDialogButtonBox>
-#include <QtGui/QFileDialog>
 #include <QtGui/QFormLayout>
 #include <QtGui/QGridLayout>
 #include <QtGui/QGroupBox>
@@ -44,7 +43,7 @@
 #include "gui/widgets/buddy-avatar-widget.h"
 #include "gui/widgets/buddy-contacts-table.h"
 #include "gui/windows/message-dialog.h"
-#include "icons-manager.h"
+#include "icons/icons-manager.h"
 #include "misc/misc.h"
 #include "model/actions-proxy-model.h"
 #include "model/roles.h"
@@ -81,6 +80,15 @@ void BuddyGeneralConfigurationWidget::createGui()
 	connect(DisplayEdit, SIGNAL(textChanged(QString)), this, SIGNAL(validChanged()));
 	DisplayEdit->setText(MyBuddy.display());
 	nameLayout->addWidget(DisplayEdit);
+	if (1 == MyBuddy.contacts().count())
+	{
+		Protocol *protocolHandler = MyBuddy.contacts().at(0).contactAccount().protocolHandler();
+		if (protocolHandler && protocolHandler->contactsListReadOnly())
+		{
+			DisplayEdit->setReadOnly(true);
+			DisplayEdit->setToolTip(tr("Protocol used by this buddy's contact does not allow changing buddy's name client-side"));
+		}
+	}
 
 	AvatarWidget = new BuddyAvatarWidget(MyBuddy, nameWidget);
 	nameLayout->addWidget(AvatarWidget);
