@@ -25,8 +25,8 @@
 #include <QtGui/QLineEdit>
 #include <QtGui/QPushButton>
 
+#include "icons/kadu-icon.h"
 #include "misc/misc.h"
-#include "icons-manager.h"
 
 #include "select-file.h"
 
@@ -38,7 +38,7 @@ SelectFile::SelectFile(const QString &type, QWidget *parent)
 	LineEdit = new QLineEdit(this);
 	connect(LineEdit, SIGNAL(editingFinished()), this, SLOT(fileEdited()));
 
-	QPushButton *selectFile = new QPushButton(IconsManager::instance()->iconByPath("document-open"), QString(), this);
+	QPushButton *selectFile = new QPushButton(KaduIcon("document-open").icon(), QString(), this);
 	connect(selectFile, SIGNAL(clicked()), this, SLOT(selectFileClicked()));
 
 	layout->addWidget(LineEdit);
@@ -55,7 +55,7 @@ SelectFile::SelectFile(QWidget *parent)
 	LineEdit = new QLineEdit(this);
 	connect(LineEdit, SIGNAL(editingFinished()), this, SLOT(fileEdited()));
 
-	QPushButton *selectFile = new QPushButton(IconsManager::instance()->iconByPath("document-open"), QString(), this);
+	QPushButton *selectFile = new QPushButton(KaduIcon("document-open").icon(), QString(), this);
 	connect(selectFile, SIGNAL(clicked()), this, SLOT(selectFileClicked()));
 
 	layout->addWidget(LineEdit);
@@ -78,7 +78,7 @@ void SelectFile::selectFileClicked()
 	}
 	else if (Type == "all")
 	{
-		QString s(QFileDialog::getOpenFileName(this, tr("Select File"), LineEdit->text(), "All Files (*)"));
+		QString s(QFileDialog::getOpenFileName(this, tr("Select File"), LineEdit->text(), tr("All Files (*)")));
 		if (!s.isEmpty())
 		{
 			LineEdit->setText(s);
@@ -87,7 +87,7 @@ void SelectFile::selectFileClicked()
 	}
 	else if (Type == "audio")
 	{
-		QString s(QFileDialog::getOpenFileName(this, tr("Select audio File"), LineEdit->text(), "Audio Files (*.wav *.au *.raw)"));
+		QString s(QFileDialog::getOpenFileName(this, tr("Select audio File"), LineEdit->text(), tr("Audio Files (*.wav *.au *.raw);;All Files (*)")));
 		if (!s.isEmpty())
 		{
 			LineEdit->setText(s);
