@@ -20,26 +20,30 @@
 #ifndef STATUS_BUTTON_H
 #define STATUS_BUTTON_H
 
-#include <QtGui/QPushButton>
+#include <QtGui/QToolButton>
 
 #include "configuration/configuration-aware-object.h"
+#include "icons/kadu-icon.h"
 #include "status/status.h"
 
 class StatusContainer;
+class StatusIcon;
 class StatusMenu;
 
-class StatusButton : public QPushButton, private ConfigurationAwareObject
+class StatusButton : public QToolButton, private ConfigurationAwareObject
 {
 	Q_OBJECT
 
 	StatusContainer *MyStatusContainer;
 	bool DisplayStatusName;
+	StatusIcon *Icon;
 
 	void createGui();
-	void update();
+	void updateStatus();
 
 private slots:
-	void statusChanged();
+	void iconUpdated(const KaduIcon &icon);
+	void statusUpdated();
 
 protected:
 	virtual void configurationUpdated();
