@@ -48,8 +48,8 @@
 
 #include "core/core.h"
 #include "debug.h"
-#include "icons-manager.h"
 #include "html_document.h"
+#include "icons/kadu-icon.h"
 #include "misc/misc.h"
 #include "os/generic/url-opener.h"
 #include "url-handlers/mail-url-handler.h"
@@ -57,7 +57,7 @@
 #include "about.h"
 
 About::About(QWidget *parent) :
-		QWidget(parent, Qt::Window)
+		QWidget(parent, Qt::Window), DesktopAwareObject(this)
 {
 	kdebugf();
 
@@ -71,15 +71,15 @@ About::About(QWidget *parent) :
 	QWidget *texts = new QWidget(center);
 
 	QLabel *l_icon = new QLabel(texts);
-	l_icon->setPixmap(IconsManager::instance()->iconByPath("kadu_icons/kadu").pixmap(64, 64));
+	l_icon->setPixmap(KaduIcon("kadu_icons/kadu").icon().pixmap(64, 64));
 
 	QLabel *l_info = new QLabel(texts);
 	l_info->setBackgroundRole(texts->backgroundRole());
 
 	l_info->setText("<font size=\"5\">Kadu</font><br /><b>"
 		+ tr("Version %1").arg(Core::version())
-		+ "</b><br />"
-		+ QString("Qt %2 (compiled with Qt %3)").arg(qVersion()).arg(QT_VERSION_STR));
+		+ "</b><br/>"
+		+ tr("Qt %2 (compiled with Qt %3)").arg(qVersion()).arg(QT_VERSION_STR));
 
 	l_info->setWordWrap(true);
 	l_info->setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum));
@@ -102,10 +102,10 @@ About::About(QWidget *parent) :
 	about_layout->addWidget(new QLabel("IRC:\nirc.freenode.net - #kadu", wb_about));
 	about_layout->addSpacing(10);
 	about_layout->addWidget(new QLabel(tr("Support:"), wb_about));
-	about_layout->addWidget(new KaduLink("http://www.kadu.net/forum/", wb_about));
+	about_layout->addWidget(new KaduLink("http://www.kadu.im/forum/", wb_about));
 	about_layout->addSpacing(20);
 	about_layout->addWidget(new QLabel("(C) 2001-2011 Kadu Team", wb_about));
-	about_layout->addWidget(new KaduLink("http://www.kadu.net/", wb_about));
+	about_layout->addWidget(new KaduLink("http://www.kadu.im/", wb_about));
 	about_layout->addStretch(100);
 
 	// create our info widgets
@@ -116,17 +116,18 @@ About::About(QWidget *parent) :
 	tb_authors->viewport()->setAutoFillBackground(false);
 	tb_authors->setTextInteractionFlags(Qt::TextBrowserInteraction);
 	QString authors = loadFile("AUTHORS");
+	authors.remove(QRegExp("[<>]"));
+	authors = Qt::escape(authors);
 	// convert the email addresses
 	authors.replace(" (at) ", "@");
 	authors.replace(" (dot) ", ".");
-	authors.remove(QRegExp("[<>]"));
 	authors.prepend("<b>");
 	authors.replace("\n   ", "</b><br/>&nbsp;&nbsp;&nbsp;");
 	authors.replace('\n', QLatin1String("</b><br/><b>"));
 	HtmlDocument authors_html;
 	authors_html.parseHtml(authors);
 	MailUrlHandler *handler = new MailUrlHandler;
-	handler->convertUrlsToHtml(authors_html);
+	handler->convertUrlsToHtml(authors_html, true);
 	delete handler;
 	tb_authors->setHtml(authors_html.generateHtml());
 
@@ -135,7 +136,7 @@ About::About(QWidget *parent) :
 	tb_thanks->setReadOnly(true);
 	tb_thanks->setFrameStyle(QFrame::NoFrame);
 	tb_thanks->viewport()->setAutoFillBackground(false);
-	QString thanks = loadFile("THANKS");
+	QString thanks = Qt::escape(loadFile("THANKS"));
 	thanks.prepend("<b>");
 	thanks.replace("\n\n", QLatin1String("</b><br/><br/>"));
 	thanks.replace("\n   ", "<br/>&nbsp;&nbsp;&nbsp;");
@@ -157,13 +158,13 @@ About::About(QWidget *parent) :
 	tb_changelog->setOpenLinks(false);
 	tb_changelog->setFrameStyle(QFrame::NoFrame);
 	tb_changelog->viewport()->setAutoFillBackground(false);
-	QString changelog = loadFile("ChangeLog");
+	QString changelog = Qt::escape(loadFile("ChangeLog"));
 	changelog.replace('\n', "<br/>");
 	HtmlDocument changelog_html;
 	changelog_html.parseHtml(changelog);
 	changelog = changelog_html.generateHtml();
-	// #bug_no -> Mantis URL
-	changelog.replace(QRegExp("#(\\d+)"), "<a href=\"http://www.kadu.net/mantis/view.php?id=\\1\">#\\1</a>");
+	// #bug_no -> Redmine URL
+	changelog.replace(QRegExp("#(\\d+)"), "<a href=\"http://www.kadu.im/redmine/issues/\\1\">#\\1</a>");
 	// bold headers with green "+++"
 	changelog.replace(QRegExp("(^|<br/>)\\+\\+\\+([^<]*)<br/>"), "\\1<b><span style=\"color:green;\">+++</span>\\2</b><br/>");
 	// bold subsystem names preceded by nice green bullets instead of "*"
