@@ -57,6 +57,7 @@ class KaduWindowActions : QObject, ConfigurationAwareObject
 	ActionDescription *Translate;
 	ActionDescription *ShowInfoPanel;
 	ActionDescription *ShowBlockedBuddies;
+	ActionDescription *ShowMyself;
 
 	ActionDescription *WriteEmail;
 	ActionDescription *CopyDescription;
@@ -75,6 +76,7 @@ class KaduWindowActions : QObject, ConfigurationAwareObject
 private slots:
 	void statusChanged(StatusContainer *container, Status status);
 
+	void showMultilogonsActionCreated(Action *action);
 	void inactiveUsersActionCreated(Action *action);
 	void descriptionUsersActionCreated(Action *action);
 	void showDescriptionsActionCreated(Action *action);
@@ -83,6 +85,8 @@ private slots:
 	void changeStatusActionCreated(Action *action);
 	void showInfoPanelActionCreated(Action *action);
 	void showBlockedActionCreated(Action *action);
+	void showMyselfActionCreated(Action *action);
+	void writeEmailActionCreated(Action *action);
 
 	void configurationActionActivated(QAction *sender, bool toggled);
 	void yourAccountsActionActivated(QAction *sender, bool toggled);
@@ -94,12 +98,12 @@ private slots:
 	void openSearchActionActivated(QAction *sender, bool toggled);
 	void helpActionActivated(QAction *sender, bool toggled);
 	void bugsActionActivated(QAction *sender, bool toggled);
-	void supportActionActivated(QAction *sender, bool toggled);
 	void getInvolvedActionActivated(QAction *sender, bool toggled);
 	void aboutActionActivated(QAction *sender, bool toggled);
 	void translateActionActivated(QAction *sender, bool toggled);
 	void showInfoPanelActionActivated(QAction *sender, bool toggled);
 	void showBlockedActionActivated(QAction *sender, bool toggled);
+	void showMyselfActionActivated(QAction *sender, bool toggled);
 
 	void writeEmailActionActivated(QAction *sender, bool toggled);
 	void copyDescriptionActionActivated(QAction *sender, bool toggled);
