@@ -38,7 +38,7 @@
 #include "contacts/contact-manager.h"
 #include "gui/widgets/groups-combo-box.h"
 #include "gui/widgets/select-buddy-combo-box.h"
-#include "icons-manager.h"
+#include "icons/icons-manager.h"
 #include "model/actions-proxy-model.h"
 #include "model/roles.h"
 
@@ -53,17 +53,28 @@ void SubscriptionWindow::getSubscription(Contact contact, QObject *receiver, con
 }
 
 SubscriptionWindow::SubscriptionWindow(Contact contact, QWidget *parent) :
-		QDialog(parent), CurrentContact(contact)
+		QDialog(parent), DesktopAwareObject(this), CurrentContact(contact)
 {
 	setWindowRole("kadu-subscription");
 
 	setAttribute(Qt::WA_DeleteOnClose);
 	setWindowTitle(tr("New Contact Request"));
 
+	// It'd be too unsafe to not add this contact to the manager now and rely later on addItem()
+	// as the contact might be added in the meantime. See bug #2222.
+	Contact knownContact = ContactManager::instance()->byId(CurrentContact.contactAccount(), CurrentContact.id(), ActionReturnNull);
+	if (knownContact)
+		CurrentContact = knownContact;
+	else
+	{
+		CurrentContact.setDirty(false);
+		ContactManager::instance()->addItem(CurrentContact);
+	}
+
 	QGridLayout *layout = new QGridLayout(this);
 	layout->setColumnStretch(2, 4);
 
-	QLabel *messageLabel = new QLabel(tr("<b>%1</b> wants to be able to chat with you.").arg(contact.id()), this);
+	QLabel *messageLabel = new QLabel(tr("<b>%1</b> wants to be able to chat with you.").arg(CurrentContact.id()), this);
 
 	QLabel *groupLabel = new QLabel(tr("Add in Group") + ':', this);
 
@@ -130,8 +141,6 @@ void SubscriptionWindow::accepted()
 		close();
 	}
 
-	ContactManager::instance()->addItem(CurrentContact);
-
 	Buddy buddy;
 	if (!MergeContact->isChecked())
 	{
