@@ -34,7 +34,7 @@ class KADUAPI PredicateObject
 {
 
 protected:
-	static KADUAPI QList<T *> Objects;
+	static QList<T *> Objects;
 
 public:
 	PredicateObject() { Objects.append(static_cast<T *>(this)); }
