@@ -29,12 +29,10 @@
 
 #include <QtCore/QDateTime>
 #include <QtCore/QObject>
-#include <QtGui/QIcon>
 
 #include "exports.h"
 
-#include "buddies/buddy.h"
-#include "buddies/buddy-list.h"
+#include "accounts/account.h"
 #include "chat/chat.h"
 #include "status/status.h"
 
@@ -55,41 +53,56 @@ class Message;
 class MultilogonService;
 class PersonalInfoService;
 class ProtocolFactory;
+class ProtocolStateMachine;
 class RosterService;
 class SearchService;
 class Status;
+class KaduIcon;
 
 class KADUAPI Protocol : public QObject
 {
 	Q_OBJECT
 	Q_DISABLE_COPY(Protocol)
 
-public:
-	enum NetworkState {
-		NetworkDisconnected,
-		NetworkConnecting,
-		NetworkConnected,
-		NetworkDisconnecting
-	};
-
-private:
 	ProtocolFactory *Factory;
+	ProtocolStateMachine *Machine;
 
 	Account CurrentAccount;
 
-	NetworkState State;
 	Status CurrentStatus;
 
+	void setAllOffline();
+
 private slots:
 	void statusChanged(StatusContainer *container, Status status);
 
-protected:
-	void setAllOffline();
+	// state machine slots
+	void prepareStateMachine();
 
-	virtual void changeStatus() = 0;
+	void loggingInStateEntered();
+	void loggedInStateEntered();
+	void loggingOutStateEntered();
+	void loggedOutAnyStateEntered();
+	void wantToLogInStateEntered();
+	void passwordRequiredStateEntered();
+
+protected:
+	Status loginStatus() const;
+
+	virtual void login() = 0;
+	virtual void afterLoggedIn() {}
+	virtual void logout() = 0;
+	virtual void sendStatusToServer() = 0;
+
+	virtual void disconnectedCleanup();
 	void statusChanged(Status newStatus);
 
-	void networkStateChanged(NetworkState state);
+protected slots:
+	void loggedIn();
+	void loggedOut();
+	void passwordRequired();
+	void connectionError();
+	void connectionClosed();
 
 public:
 	Protocol(Account account, ProtocolFactory *factory);
@@ -112,26 +125,22 @@ public:
 	virtual bool contactsListReadOnly() = 0;
 	virtual bool supportsPrivateStatus() { return false; }
 
-	NetworkState state() { return State; }
-	bool isConnected() { return (State == NetworkConnected); }
-	bool isConnecting() { return (State == NetworkConnecting); }
+	bool isConnected();
+	bool isConnecting();
 
 	void setStatus(Status status);
 	Status status() const;
-	Status nextStatus() const;
 	virtual int maxDescriptionLength() { return -1; }
 
 	virtual void changePrivateMode() = 0;
 
 	virtual QString statusPixmapPath() = 0;
 
-	virtual QIcon statusIcon(Status status);
-	virtual QString statusIconPath(const QString &statusType);
-	virtual QString statusIconFullPath(const QString &statusType);
-	virtual QIcon statusIcon(const QString &statusType);
-	QIcon statusIcon() { return statusIcon(CurrentStatus); }
+	KaduIcon statusIcon();
+	KaduIcon statusIcon(const Status &status);
+	KaduIcon statusIcon(const QString &statusType);
 
-	QIcon icon();
+	KaduIcon icon();
 
 	// TODO: workaround
 	void emitContactStatusChanged(Contact contact, Status oldStatus)
@@ -140,12 +149,11 @@ public:
 	}
 
 public slots:
-	virtual void login(const QString &password, bool permanent) = 0;
+	void passwordProvided();
 
 signals:
 	void connecting(Account account);
 	void connected(Account account);
-	void disconnecting(Account account);
 	void disconnected(Account account);
 
 	void statusChanged(Account account, Status newStatus);
@@ -155,6 +163,20 @@ signals:
 	void connectionError(Account account, const QString &server, const QString &reason);
 	void invalidPassword(Account account);
 
+// state machine signals
+	void stateMachineLoggedIn();
+	void stateMachineLoggedOut();
+
+	void stateMachineChangeStatus();
+	void stateMachineLogout();
+
+	void stateMachinePasswordRequired();
+	void stateMachinePasswordAvailable();
+	void stateMachinePasswordNotAvailable();
+
+	void stateMachineConnectionError();
+	void stateMachineConnectionClosed();
+
 };
 
 #endif // PROTOCOL_H
