@@ -163,7 +163,7 @@ void Updates::run()
 
 	UpdateChecked = true;
 
-	HttpClient = new QHttp("www.kadu.net", 80, this);
+	HttpClient = new QHttp("www.kadu.im", 80, this);
 	connect(HttpClient, SIGNAL(readyRead(const QHttpResponseHeader &)),
 			this, SLOT(gotUpdatesInfo(const QHttpResponseHeader &)));
 	HttpClient->get(Query);
@@ -174,12 +174,12 @@ bool Updates::isNewerVersion(const QString &newestversion)
 	QStringList actual = stripVersion(Core::version()).split('.', QString::SkipEmptyParts);
 	QStringList newest = stripVersion(newestversion).split('.', QString::SkipEmptyParts);
 
-	if (newest.at(0).toInt() > actual.at(0).toInt())
-		return true;
-	if (newest.at(1).toInt() > actual.at(1).toInt())
-		return true;
-	if (newest.at(2).toInt() > actual.at(2).toInt())
-		return true;
+	if (newest.at(0).toInt() != actual.at(0).toInt())
+		return newest.at(0).toInt() > actual.at(0).toInt();
+	if (newest.at(1).toInt() != actual.at(1).toInt())
+		return newest.at(1).toInt() > actual.at(1).toInt();
+	if (newest.at(2).toInt() != actual.at(2).toInt())
+		return newest.at(2).toInt() > actual.at(2).toInt();
 	if (newest.length() > actual.length())
 		return true;
 	if (newest.length() == 4)
