@@ -39,7 +39,7 @@ bool StandardUrlHandler::isUrlValid(const QByteArray &url)
 	return UrlRegExp.exactMatch(QString::fromUtf8(url));
 }
 
-void StandardUrlHandler::convertUrlsToHtml(HtmlDocument &document)
+void StandardUrlHandler::convertUrlsToHtml(HtmlDocument &document, bool generateOnlyHrefAttr)
 {
 	for (int i = 0; i < document.countElements(); ++i)
 	{
@@ -61,11 +61,24 @@ void StandardUrlHandler::convertUrlsToHtml(HtmlDocument &document)
 		if (!aLink.contains("://"))
 			aLink.prepend("http://");
 
-		if ((length - index > LinkFoldTreshold) && FoldLink)
+		if (FoldLink && (length - index > LinkFoldTreshold))
+		{
 			displayLink = Qt::escape(text.mid(index, index + (LinkFoldTreshold / 2)) + "..."
 					+ text.mid(length - (LinkFoldTreshold / 2), LinkFoldTreshold / 2));
 
-		link = "<a href=\"" + aLink + "\" title=\"" + aLink + "\">" + displayLink + "</a>";
+			if (generateOnlyHrefAttr)
+				link = "<a href=\"" + aLink + "\">" + displayLink + "</a>";
+			else
+				// prepare string for KaduWebView::convertClipboardHtml()
+				link = "<a folded=\"1\" displaystr=\"" + displayLink + "\" href=\"" + aLink + "\" title=\"" + aLink + "\">" + displayLink + "</a>";
+		}
+		else
+		{
+			if (generateOnlyHrefAttr)
+				link = "<a href=\"" + aLink + "\">" + displayLink + "</a>";
+			else
+				link = "<a href=\"" + aLink + "\" title=\"" + aLink + "\">" + displayLink + "</a>";
+		}
 
 		document.splitElement(i, index, length);
 		document.setElementValue(i, link, true);
