@@ -29,7 +29,7 @@ public:
 
 	virtual bool isUrlValid(const QByteArray &url) = 0;
 
-	virtual void convertUrlsToHtml(HtmlDocument &document) = 0;
+	virtual void convertUrlsToHtml(HtmlDocument &document, bool generateOnlyHrefAttr) = 0;
 
 	virtual void openUrl(const QByteArray &url, bool disableMenu = false) = 0;
 };
